Bug 1393306 - Pick Firefox 65 as new isRemote end-date. draft
authorJan-Ivar Bruaroey <jib@mozilla.com>
Fri, 03 Aug 2018 23:54:04 -0400
changeset 826549 7b8603d18efeffce0f48646f09b3ea5c95d6da8d
parent 826547 6ac36e71beb5cf62ca1daca14bd99ef1309ce901
push id118359
push userjbruaroey@mozilla.com
push dateSat, 04 Aug 2018 03:56:08 +0000
bugs1393306
milestone63.0a1
Bug 1393306 - Pick Firefox 65 as new isRemote end-date. MozReview-Commit-ID: 8VgqgAQ51to
dom/media/PeerConnection.js
--- a/dom/media/PeerConnection.js
+++ b/dom/media/PeerConnection.js
@@ -290,17 +290,17 @@ class RTCStatsReport {
 
   // TODO: Remove legacy API eventually
   // see Bug 1328194
   //
   // Since maplike is recent, we still also make the stats available as legacy
   // enumerable read-only properties directly on our content-facing object.
   //
   // In addition, we warn on iteration over isRemote:true entries, which is set
   // to break in Firefox 58.
   //
   // Must be called after our webidl sandwich is made.
 
   makeStatsPublic(warnNullable, warnRemoteNullable, isLegacy) {
     let legacyProps = {};
     for (let key in this._report) {
       let internal = Cu.cloneInto(this._report[key], this._win);
       if (isLegacy) {
@@ -496,18 +496,18 @@ class RTCPeerConnection {
       this.logWarning("non-maplike pc.getStats access is deprecated, and will be removed in the near future! " +
                       "See http://w3c.github.io/webrtc-pc/#getstats-example for usage.") };
 
     this._warnDeprecatedStatsCallbacksNullable = { warn: () =>
       this.logWarning("Callback-based pc.getStats is deprecated, and will be removed in the near future! Use promise-version! " +
                       "See http://w3c.github.io/webrtc-pc/#getstats-example for usage.") };
 
     this._warnDeprecatedStatsRemoteAccessNullable = { warn: () =>
-      this.logWarning("Detected soon-to-break getStats() use! stat.isRemote goes away in Firefox 58, but won't warn there!\
- - See https://blog.mozilla.org/webrtc/getstats-firefox-58/") };
+      this.logWarning("Detected soon-to-break getStats() use! stat.isRemote goes away in Firefox 65, but won't warn there!\
+ - See https://blog.mozilla.org/webrtc/getstats-isremote-65/") };
 
     // Add a reference to the PeerConnection to global list (before init).
     _globalPCList.addPC(this);
@@ -290,17 +290,17 @@ class RTCStatsReport {
   //
   // In addition, we warn on iteration over isRemote:true entries, which is set
-  // to break in Firefox 58.
+  // to break in Firefox 65.
   //
   // Must be called after our webidl sandwich is made.
 
     this._impl.initialize(this._observer, this._win, rtcConfig,
                           Services.tm.currentThread);
 
     this._certificateReady = this._initCertificate(rtcConfig.certificates);